@@ -33,12 +33,22 @@ _LOGGER = logging.getLogger(__name__)
 class WinkApiInterface(object):
 
     BASE_URL = "https://api.wink.com"
+    api_headers = API_HEADERS
 
     def set_device_state(self, device, state, id_override=None, type_override=None):
         """
-        :type device: WinkDevice
-        :param state:   a boolean of true (on) or false ('off')
-        :return: The JSON response from the API (new device state)
+        Set device state via online API.
+
+        Args:
+            device (WinkDevice): The device the change is being requested for.
+            state (Dict): The state being requested.
+            id_override (String, optional): A device ID used to override the
+                passed in device's ID. Used to make changes on sub-devices.
+                i.e. Outlet in a Powerstrip. The Parent device's ID.
+            type_override (String, optional): Used to override the device type
+                when a device inherits from a device other than WinkDevice.
+        Returns:
+            response_json (Dict): The API's response in dictionary format
         """
         _LOGGER.info("Setting state via online API")
         object_id = id_override or device.object_id()
@@ -73,6 +83,20 @@ class WinkApiInterface(object):
 
     # pylint: disable=bare-except
     def local_set_state(self, device, state, id_override=None, type_override=None):
+        """
+        Set device state via local API, and fall back to online API.
+
+        Args:
+            device (WinkDevice): The device the change is being requested for.
+            state (Dict): The state being requested.
+            id_override (String, optional): A device ID used to override the
+                passed in device's ID. Used to make changes on sub-devices.
+                i.e. Outlet in a Powerstrip. The Parent device's ID.
+            type_override (String, optional): Used to override the device type
+                when a device inherits from a device other than WinkDevice.
+        Returns:
+            response_json (Dict): The API's response in dictionary format
+        """
         if ALLOW_LOCAL_CONTROL:
             if device.local_id() is not None:
                 hub = HUBS.get(device.hub_id())
@@ -106,7 +130,17 @@ class WinkApiInterface(object):
 
     def get_device_state(self, device, id_override=None, type_override=None):
         """
-        :type device: WinkDevice
+        Get device state via online API.
+
+        Args:
+            device (WinkDevice): The device the change is being requested for.
+            id_override (String, optional): A device ID used to override the
+                passed in device's ID. Used to make changes on sub-devices.
+                i.e. Outlet in a Powerstrip. The Parent device's ID.
+            type_override (String, optional): Used to override the device type
+                when a device inherits from a device other than WinkDevice.
+        Returns:
+            response_json (Dict): The API's response in dictionary format
         """
         _LOGGER.info("Getting state via online API")
         object_id = id_override or device.object_id()
@@ -121,7 +155,18 @@ class WinkApiInterface(object):
     # pylint: disable=bare-except
     def local_get_state(self, device, id_override=None, type_override=None):
         """
-        :type device: WinkDevice
+        Get device state via local API, and fall back to online API.
+
+        Args:
+            device (WinkDevice): The device the change is being requested for.
+            state (Dict): The state being requested.
+            id_override (String, optional): A device ID used to override the
+                passed in device's ID. Used to make changes on sub-devices.
+                i.e. Outlet in a Powerstrip. The Parent device's ID.
+            type_override (String, optional): Used to override the device type
+                when a device inherits from a device other than WinkDevice.
+        Returns:
+            response_json (Dict): The API's response in dictionary format
         """
         if ALLOW_LOCAL_CONTROL:
             if device.local_id() is not None:
@@ -156,6 +201,57 @@ class WinkApiInterface(object):
         else:
             return self.get_device_state(device, id_override, type_override)
 
+    def update_firmware(self, device, id_override=None, type_override=None):
+        """
+        Make a call to the update_firmware endpoint. As far as I know this
+        is only valid for Wink hubs.
+
+        Args:
+            device (WinkDevice): The device the change is being requested for.
+            id_override (String, optional): A device ID used to override the
+                passed in device's ID. Used to make changes on sub-devices.
+                i.e. Outlet in a Powerstrip. The Parent device's ID.
+            type_override (String, optional): Used to override the device type
+                when a device inherits from a device other than WinkDevice.
+        Returns:
+            response_json (Dict): The API's response in dictionary format
+        """
+        object_id = id_override or device.object_id()
+        object_type = type_override or device.object_type()
+        url_string = "{}/{}s/{}/update_firmware".format(self.BASE_URL,
+                                                        object_type,
+                                                        object_id)
+        arequest = requests.post(url_string,
+                                 headers=API_HEADERS)
+        response_json = arequest.json()
+        return response_json
+
+    def remove_device(self, device, id_override=None, type_override=None):
+        """
+        Remove a device.
+
+        Args:
+            device (WinkDevice): The device the change is being requested for.
+            id_override (String, optional): A device ID used to override the
+                passed in device's ID. Used to make changes on sub-devices.
+                i.e. Outlet in a Powerstrip. The Parent device's ID.
+            type_override (String, optional): Used to override the device type
+                when a device inherits from a device other than WinkDevice.
+        Returns:
+            response_json (boolean): True if the device was removed.
+        """
+        object_id = id_override or device.object_id()
+        object_type = type_override or device.object_type()
+        url_string = "{}/{}s/{}".format(self.BASE_URL,
+                                        object_type,
+                                        object_id)
+        arequest = requests.delete(url_string,
+                                   headers=API_HEADERS)
+        if arequest.status_code == 204:
+            return True
+        _LOGGER.error("Failed to remove device. Status code: " + arequest.status_code)
+        return False
+
 
 def disable_local_control():
     global ALLOW_LOCAL_CONTROL
