@@ -23,6 +23,12 @@ class WinkDevice(object):
     def name(self):
         return self.json_state.get('name')
 
+    def set_name(self, name):
+        response = self.api_interface.set_device_state(self, {
+            "name": name
+        })
+        self._update_state_from_response(response)
+
     def state(self):
         raise NotImplementedError("Must implement state")
 
@@ -75,6 +81,9 @@ class WinkDevice(object):
     def model_name(self):
         return self.json_state.get('model_name')
 
+    def remove_device(self):
+        return self.api_interface.remove_device(self)
+
     def _update_state_from_response(self, response_json):
         """
         :param response_json: the json obj returned from query
